@@ -7,12 +7,13 @@ from jenkins_job_manager.xml_change import (
     DELETE,
 )
 
+import fnmatch
+import glob
 import itertools
 import logging
-import fnmatch
 import os
-import re
 import random
+import re
 import string
 import xml.dom.minidom
 import xml.etree.ElementTree
@@ -25,7 +26,6 @@ from jenkins_jobs.parser import YamlParser
 from jenkins_jobs.registry import ModuleRegistry
 from jenkins_jobs.xml_config import XmlJob, XmlJobGenerator, XmlViewGenerator
 
-
 logging.basicConfig(level=logging.INFO)
 log = logging.getLogger("jjm")
 
@@ -99,6 +99,20 @@ class JenkinsJobManager:
             return False
         return True
 
+    def read_views(self):
+        """read existing views from jenkins"""
+        jenkins = self.jenkins
+        views = self.views
+        log.info("Reading jenkins views state")
+        for view_d in jenkins.get_views():
+            log.debug("found view %r", view_d)
+            name, url, _class = view_d["name"], view_d["url"], view_d.get("_class")
+            if name == "all" or _class == "hudson.model.AllView":
+                log.debug("ignoring all view: %r", view_d)
+                continue
+            view_config = jenkins.get_view_config(name)
+            views[name].before_xml = view_config
+
     def read_jobs(self):
         """read existing jobs from jenkins"""
         jenkins = self.jenkins
@@ -216,8 +230,8 @@ class JenkinsJobManager:
                 return xml_job
 
         jjb_config = self.get_jjb_config()
-        options_names = []  # normally a list of jobs globs
-        files_path = ["."]
+        options_names = []  # normally a list of jobs globs for targeting
+        files_path = glob.glob("./**/", recursive=True)
 
         parser = YamlParser(jjb_config)
         registry = ModuleRegistry(jjb_config, self.plugins_list)
@@ -257,6 +271,7 @@ class JenkinsJobManager:
         if target_job_names:
             log.debug("target_job_names=%r", target_job_names)
             self._jobs_filter_func = NameRegexFilter.from_glob_list(target_job_names)
+        self.read_views()
         self.read_jobs()
         self.load_plugins_list()
         self.generate_jjb_xml()
